local fs = require "nixio.fs"
local config_file = "/etc/vsftpd.conf" 
local users_file = "/etc/vsftpd.users"
local chroot_file = "/etc/vsftpd.chroot_list"

f = SimpleForm("vsftpd", "vsftpd configuration", "Here can you change your vsftpd configuration.")

t = f:field(TextValue, "vsftpd_config", "Edit the /etc/vsftpd.config file for general settings")
t.rmempty = true
t.rows = 20
function t.cfgvalue()
	return fs.readfile(config_file) or ""
end

u = f:field(TextValue, "vsftpd_users", "Edit the /etc/vsftpd.users file for allowed users (one user per line)")
u.rmempty = true
u.rows = 10
function u.cfgvalue()
	return fs.readfile(users_file) or ""
end

c = f:field(TextValue, "vsftpd_chroot", "Edit the /etc/vsftpd.chroot_list file for chrooting users (one user per line)")
c.rmempty = true
c.rows = 10
function c.cfgvalue()
	return fs.readfile(chroot_file) or ""
end

function f.handle(self, state, data)
	if state == FORM_VALID then
		if data.vsftpd_config then
			fs.writefile(config_file, data.vsftpd_config:gsub("\r\n", "\n"))
		end
		if data.vsftpd_users then
			fs.writefile(users_file, data.vsftpd_users:gsub("\r\n", "\n"))
		end
		if data.vsftpd_chroot then
			fs.writefile(chroot_file, data.vsftpd_chroot:gsub("\r\n", "\n"))
		end
		luci.sys.exec("/etc/init.d/vsftpd stop")
		luci.sys.exec("/etc/init.d/vsftpd start")
	end
	return true
end

return f
